@@ -7,7 +7,7 @@ use Moo::Role;
 
 use Data::Record::Serialize::Error { errors => [ '::create' ] }, -all;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use IO::File;
 
@@ -26,6 +26,8 @@ has fh => (
           : ( IO::File->new( $self->output, 'w' )
               or error( '::create', "unable to create @{[ $self->output ]}" ) );
     },
+   predicate => 1,
+   clearer => 1,
 );
 
 
@@ -35,9 +37,15 @@ has fh => (
 
 
 
+
 sub print { shift->fh->print( @_ ) }
 sub say   { shift->fh->say( @_ ) }
-sub close { shift->fh->close }
+
+sub close {
+    my $self = shift;
+    $self->fh->close if $self->has_fh;
+    $self->clear_fh;
+}
 
 with 'Data::Record::Serialize::Role::Sink';
 
@@ -65,7 +73,7 @@ Data::Record::Serialize::Sink::stream - output encoded data to a stream.
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -85,6 +93,7 @@ It performs the L<Data::Record::Serialize::Role::Sink> role.
 =for Pod::Coverage print
  say
  close
+ has_fh
 
 =head1 INTERFACE
 
